@@ -31,7 +31,9 @@ class EasyDict(dict):
     >>> d = {'a': 1}
     >>> EasyDict(**d)
     {'a': 1}
-
+    >>> EasyDict((('a', 1), ('b', 2)))
+    {'a': 1, 'b': 2}
+    
     Set attributes
 
     >>> d = EasyDict()
@@ -54,12 +56,12 @@ class EasyDict(dict):
     >>> isinstance(d.bar, list)
     True
     >>> from operator import attrgetter
-    >>> map(attrgetter('x'), d.bar)
+    >>> list(map(attrgetter('x'), d.bar))
     [1, 3]
-    >>> map(attrgetter('y'), d.bar)
+    >>> list(map(attrgetter('y'), d.bar))
     [2, 4]
     >>> d = EasyDict()
-    >>> d.keys()
+    >>> list(d.keys())
     []
     >>> d = EasyDict(foo=3, bar=dict(x=1, y=2))
     >>> d.foo
@@ -70,7 +72,7 @@ class EasyDict(dict):
     Still like a dict though
 
     >>> o = EasyDict({'clean':True})
-    >>> o.items()
+    >>> list(o.items())
     [('clean', True)]
 
     And like a class
@@ -112,6 +114,8 @@ class EasyDict(dict):
     def __init__(self, d=None, **kwargs):
         if d is None:
             d = {}
+        else:
+            d = dict(d)        
         if kwargs:
             d.update(**kwargs)
         for k, v in d.items():
